@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__bytes", GLOBAL_NS)
 }
 
-pub fn bytes(options: &Options) -> String {
+pub fn bytes() -> String {
     format!(
         "
 // Bytes
@@ -16,9 +16,9 @@ void {fn_attributes} {ns}__set_raw({bytes_blob} *self_blob, {byte_list_blob} raw
 void {fn_attributes} {ns}__push({bytes_blob} *self_blob, {byte_blob} byte_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        bytes_blob = options.bytes_blob_name,
-        byte_list_blob = options.byte_list_blob_name,
-        byte_blob = options.byte_blob_name
+        fn_attributes = options().fn_attributes,
+        bytes_blob = options().bytes_blob_name,
+        byte_list_blob = options().byte_list_blob_name,
+        byte_blob = options().byte_blob_name
     )
 }
