@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__input_error", GLOBAL_NS)
 }
 
-pub fn input_error(options: &Options) -> String {
+pub fn input_error() -> String {
     format!(
         "
 // InputError
@@ -17,8 +17,8 @@ const {string_ptr_blob} *{fn_attributes} {ns}__get_unsupported_encoding(const {i
 const {string_ptr_blob} *{fn_attributes} {ns}__get_decoding_error(const {input_error_blob}* self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        input_error_blob = options.input_error_blob_name,
-        string_ptr_blob = options.string_ptr_blob_name
+        fn_attributes = options().fn_attributes,
+        input_error_blob = options().input_error_blob_name,
+        string_ptr_blob = options().string_ptr_blob_name
     )
 }
