@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__magic_comment", GLOBAL_NS)
 }
 
-pub fn magic_comment(options: &Options) -> String {
+pub fn magic_comment() -> String {
     format!(
         "
 // MagicComment
@@ -18,9 +18,9 @@ const {loc_blob} *{fn_attributes} {ns}__get_key_l(const {magic_comment_blob} *se
 const {loc_blob} *{fn_attributes} {ns}__get_value_l(const {magic_comment_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        magic_comment_blob = options.magic_comment_blob_name,
-        magic_comment_kind_blob = options.magic_comment_kind_blob_name,
-        loc_blob = options.loc_blob_name,
+        fn_attributes = options().fn_attributes,
+        magic_comment_blob = options().magic_comment_blob_name,
+        magic_comment_kind_blob = options().magic_comment_kind_blob_name,
+        loc_blob = options().loc_blob_name,
     )
 }
