@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__token", GLOBAL_NS)
 }
 
-pub fn token(options: &Options) -> String {
+pub fn token() -> String {
     format!(
         "
 // Token
@@ -24,9 +24,9 @@ uint32_t {fn_attributes} {ns}__get_lex_state_before(const {token_blob} *self_blo
 uint32_t {fn_attributes} {ns}__get_lex_state_after(const {token_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        token_blob = options.token_blob_name,
-        bytes_blob = options.bytes_blob_name,
-        loc_blob = options.loc_blob_name,
+        fn_attributes = options().fn_attributes,
+        token_blob = options().token_blob_name,
+        bytes_blob = options().bytes_blob_name,
+        loc_blob = options().loc_blob_name,
     )
 }
