@@ -1,5 +1,5 @@
 use super::{fields, ns};
-use crate::Options;
+use crate::options;
 use lib_ruby_parser_nodes::Message;
 
 /// Returns name of the message constructor for the given `message`
@@ -11,13 +11,13 @@ pub fn name(message: &Message) -> String {
     )
 }
 
-fn arglist(message: &Message, options: &Options) -> String {
+fn arglist(message: &Message) -> String {
     message
         .fields
         .map(|field| {
             format!(
                 "{field_type} {field_name}_blob",
-                field_type = fields::field_type(field, options),
+                field_type = fields::field_type(field),
                 field_name = fields::field_name(field)
             )
         })
@@ -25,12 +25,12 @@ fn arglist(message: &Message, options: &Options) -> String {
 }
 
 /// Returns C signature of the message constructor for the given `message`
-pub fn sig(message: &Message, options: &Options) -> String {
+pub fn sig(message: &Message) -> String {
     format!(
         "{diagnostic_message_blob} {fn_attributes} {constructor_name}({arglist})",
-        diagnostic_message_blob = options.diagnostic_message_blob_name,
-        fn_attributes = options.fn_attributes,
+        diagnostic_message_blob = options().diagnostic_message_blob_name,
+        fn_attributes = options().fn_attributes,
         constructor_name = name(message),
-        arglist = arglist(message, options)
+        arglist = arglist(message)
     )
 }
