@@ -1,5 +1,4 @@
 use super::fields;
-use crate::Options;
 use lib_ruby_parser_nodes::Node;
 
 /// Returns name of the internal struct representing given `node`
@@ -8,11 +7,11 @@ pub fn name(node: &Node) -> String {
 }
 
 /// Returns definition of the internal struct representing given `node`
-pub fn definition(node: &Node, options: &Options) -> String {
+pub fn definition(node: &Node) -> String {
     let fields = node.fields.map(|field| {
         format!(
             "{} {};",
-            fields::field_type(field, options),
+            fields::field_type(field),
             fields::field_name(field)
         )
     });
