@@ -4,8 +4,8 @@ use std::process::Command;
 #[test]
 fn test_generate() {
     let options = Options {
-        pre_code: String::from("#include \"stubs.h\""),
-        fn_attributes: String::from("__attribute__((always_inline))"),
+        pre_code: "#include \"stubs.h\"",
+        fn_attributes: "__attribute__((always_inline))",
         ..Default::default()
     };
     let contents = generate(&options);
